"""
Measures the area, intensity mean and sum of a specific region (here the fluorescent cells) that is within a ROI and limited by a cutoff threshold.

"""

from ij import IJ
from ij.io import FileSaver
from ij.plugin.frame import RoiManager


# Instatiate ROIManager and load current ROIManager into it. If there is none, just open one so that it does not crash.
rm = RoiManager.getInstance()
if rm == None:
	rm = RoiManager()

# Show the ROIs, convert to gray-scale, set cutoff threshold (only remove low values).
rm.runCommand("Show All");
IJ.run("8-bit");
IJ.run("Threshold...");
IJ.setThreshold(34, 255);
IJ.run("Close");

# Define output and measure.
IJ.run("Set Measurements...", "area mean standard min integrated limit display redirect=None decimal=3");
rm.runCommand("Measure");

# Saves the Results.csv in the specified directory.
#path = IJ.getDirectory("Select directory to save Results.csv file")
#IJ.saveAs("Results", path + "Results.csv")

print "Done\n"